@@ -1,12 +1,12 @@
 #ifndef LINT
-static char *rcsid="$Id: clamav.c 436 2006-12-17 11:06:26Z crosser $";
+static char *rcsid="$Id: clamav.c 483 2009-03-29 16:41:19Z crosser $";
 #endif
 
 /*
 	WHAT IS IT:
 		modularized contentfilter for Zmailer
 	COPYRIGHT:
-		(c) 2003-2005 Eugene G. Crosser <crosser@average.org>
+		(c) 2003-2009 Eugene G. Crosser <crosser@average.org>
 	LICENSE:
 		The same set as apply to Zmailer code
 */
@@ -87,8 +87,15 @@ clamav_setup(void **priv)
 
 	snprintf(fbuf,sizeof(fbuf),"%s/%s",modconfdir(),CONFFILE);
 	cfg=clamav_config(fbuf);
+#ifdef HAVE_CL_INIT
+	rc=cl_init(CL_INIT_DEFAULT);
+	if (rc) {
+		ERRLOG((LOG_ERR,"clamav: cl_init error %s (%d)\n",
+				cl_strerror(rc),rc));
+		return rc;
+	}
+#endif
 	cfg->finaldbdir=cfg->dbdir?cfg->dbdir:cl_retdbdir();
-	(*priv)=(void *)cfg;
 	rc=clamav_refreshdb(cfg);
 	if (rc) return rc;
 	ERRLOG((LOG_INFO,"clamav: use %s scanning",
@@ -96,6 +103,7 @@ clamav_setup(void **priv)
 	ERRLOG((LOG_INFO,"clamav: %s (%s); libclamav level %d version %s OK",
 		VERSION,rcsid,cl_retflevel(),cl_retver()));
 
+	(*priv)=(void *)cfg;
 	return 0;
 }
 
@@ -105,7 +113,11 @@ clamav_term(void **priv)
 	clamav_cfg_t *cfg=*((clamav_cfg_t **)priv);
 
 	if (cfg) {
+#ifdef HAVE_CL_INIT
+		cl_engine_free(cfg->root);
+#else
 		cl_free(cfg->root);
+#endif
 		free(cfg);
 	}
 	*priv=NULL;
@@ -166,16 +178,21 @@ clamav_scan(char *stage,int depth,slab_t data,varpool_t vp,void *priv)
 		}
 		pre_scan();
 		rc=cl_scandesc(fileno(tmpf),&virname,NULL,cfg->root,
-			&cfg->limits,cfg->clamopts);
+#ifndef HAVE_CL_INIT
+			&cfg->limits,
+#endif
+					cfg->clamopts);
 		post_scan();
 		DPRINT(("clamav file scan result=%d (%s)\n",
 				rc,rc?virname:"-"));
 		bailout:
 		if (tmpf) fclose(tmpf);
+#ifdef HAVE_CL_SCANBUFF
 	} else {
 		pre_scan();
 		rc=cl_scanbuff(data.beg,slab_size(data),&virname,cfg->root);
 		post_scan();
+#endif
 	}
 	switch (rc) {
 	case CL_CLEAN:
